@@ -364,6 +364,9 @@ def fis_bs_mekko(ynp_values,xnp_values,x_label,figsize=(12,7),color1='#97ACCF',c
     return f, ax
 
 def fis_bs_sankey(source, target, value,labels_sr,labels_tr,label_show=False, opacity_ins=0.5):
+    """
+    Gráfico tipo Sankey
+    """
     opacity = str(opacity_ins)
     color_rgb = []
     color_rgb.append('rgba(151, 172, 207, %s)'%(opacity))
@@ -420,6 +423,10 @@ def fis_bs_sankey(source, target, value,labels_sr,labels_tr,label_show=False, op
     return Image(img_bytes)
     
 def fis_tools_date_elements(df):
+    """
+    Extracción de los elementos para un DataFrame con la fecha indexada y convertidos
+    en nuevas columnas
+    """
     month = df.index.month
     year = df.index.year
     day = df.index.day
